@@ -18,7 +18,7 @@ def configuration(parent_package='',top_path=None):
         print "(ex: \"echo '/path/to/Rockstar-0.99' > rockstar.cfg\" )"
         sys.exit(1)
     config.add_extension("rockstar_interface",
-                         "yt/analysis_modules/halo_finding/rockstar/rockstar_interface.c",
+                         "yt/analysis_modules/halo_finding/rockstar/rockstar_interface.pyx",
                          library_dirs=[rd],
                          libraries=["rockstar"],
                          include_dirs=[rd,
