@@ -10,7 +10,7 @@ def configuration(parent_package='', top_path=None):
     from numpy.distutils.misc_util import Configuration
     config = Configuration('ramses', parent_package, top_path)
     config.add_extension("_ramses_reader",
-        ["yt/frontends/ramses/_ramses_reader.cpp"],
+        ["yt/frontends/ramses/_ramses_reader.pyx"],
         language="c++",
         include_dirs=["yt/frontends/ramses/ramses_headers/"],
         libraries=["stdc++"],
