@@ -65,7 +65,7 @@ def configuration(parent_package='', top_path=None):
                          libraries=["m", "hdf5"],
                          library_dirs=library_dirs, include_dirs=include_dirs)
     config.add_extension("libconfig_wrapper",
-        ["yt/utilities/libconfig_wrapper.c"] +
+        ["yt/utilities/libconfig_wrapper.pyx"] +
          glob.glob("yt/utilities/_libconfig/*.c"),
         include_dirs=["yt/utilities/_libconfig/"],
         define_macros=[("HAVE_XLOCALE_H", True)]
