@@ -28,67 +28,69 @@ from yt.utilities.definitions import \
     x_dict, \
     y_dict, \
     axis_names
+from .volume_rendering.api import off_axis_projection
+from yt.data_objects.image_array import ImageArray
 import _MPL
-import numpy as na
+import numpy as np
 import weakref
 
 class FixedResolutionBuffer(object):
+    r"""
+    FixedResolutionBuffer(data_source, bounds, buff_size, antialias = True)
+
+    This accepts a 2D data object, such as a Projection or Slice, and
+    implements a protocol for generating a pixelized, fixed-resolution
+    image buffer.
+
+    yt stores 2D AMR data internally as a set of 2D coordinates and the
+    half-width of individual pixels.  Converting this to an image buffer
+    requires a deposition step, where individual variable-resolution pixels
+    are deposited into a buffer of some resolution, to create an image.
+    This object is an interface to that pixelization step: it can deposit
+    multiple fields.  It acts as a standard AMRData object, such that
+    dict-style access returns an image of a given field.
+
+    Parameters
+    ----------
+    data_source : :class:`yt.data_objects.data_containers.AMRProjBase` or :class:`yt.data_objects.data_containers.AMRSliceBase`
+        This is the source to be pixelized, which can be a projection or a
+        slice.  (For cutting planes, see
+        `yt.visualization.fixed_resolution.ObliqueFixedResolutionBuffer`.)
+    bounds : sequence of floats
+        Bounds are the min and max in the image plane that we want our
+        image to cover.  It's in the order of (xmin, xmax, ymin, ymax),
+        where the coordinates are all in the appropriate code units.
+    buff_size : sequence of ints
+        The size of the image to generate.
+    antialias : boolean
+        This can be true or false.  It determines whether or not sub-pixel
+        rendering is used during data deposition.
+    periodic : boolean
+        This can be true or false, and governs whether the pixelization
+        will span the domain boundaries.
+
+    See Also
+    --------
+    :class:`yt.visualization.fixed_resolution.ObliqueFixedResolutionBuffer` : A similar object,
+                                                     used for cutting
+                                                     planes.
+
+    Examples
+    --------
+    To make a projection and then several images, you can generate a
+    single FRB and then access multiple fields:
+
+    >>> proj = pf.h.proj(0, "Density")
+    >>> frb1 = FixedResolutionBuffer(proj, (0.2, 0.3, 0.4, 0.5),
+                    (1024, 1024))
+    >>> print frb1["Density"].max()
+    1.0914e-9
+    >>> print frb1["Temperature"].max()
+    104923.1
+    """
     _exclude_fields = ('pz','pdz','dx','x','y','z')
     def __init__(self, data_source, bounds, buff_size, antialias = True,
                  periodic = False):
-        r"""
-        FixedResolutionBuffer(data_source, bounds, buff_size, antialias = True)
-
-        This accepts a 2D data object, such as a Projection or Slice, and
-        implements a protocol for generating a pixelized, fixed-resolution
-        image buffer.
-
-        yt stores 2D AMR data internally as a set of 2D coordinates and the
-        half-width of individual pixels.  Converting this to an image buffer
-        requires a deposition step, where individual variable-resolution pixels
-        are deposited into a buffer of some resolution, to create an image.
-        This object is an interface to that pixelization step: it can deposit
-        multiple fields.  It acts as a standard AMRData object, such that
-        dict-style access returns an image of a given field.
-
-        Parameters
-        ----------
-        data_source : :class:`yt.data_objects.data_containers.AMRProjBase` or :class:`yt.data_objects.data_containers.AMRSliceBase`
-            This is the source to be pixelized, which can be a projection or a
-            slice.  (For cutting planes, see
-            `yt.visualization.fixed_resolution.ObliqueFixedResolutionBuffer`.)
-        bounds : sequence of floats
-            Bounds are the min and max in the image plane that we want our
-            image to cover.  It's in the order of (xmin, xmax, ymin, ymax),
-            where the coordinates are all in the appropriate code units.
-        buff_size : sequence of ints
-            The size of the image to generate.
-        antialias : boolean
-            This can be true or false.  It determines whether or not sub-pixel
-            rendering is used during data deposition.
-        periodic : boolean
-            This can be true or false, and governs whether the pixelization
-            will span the domain boundaries.
-
-        See Also
-        --------
-        :class:`yt.visualization.fixed_resolution.ObliqueFixedResolutionBuffer` : A similar object,
-                                                         used for cutting
-                                                         planes.
-
-        Examples
-        --------
-        To make a projection and then several images, you can generate a
-        single FRB and then access multiple fields:
-
-        >>> proj = pf.h.proj(0, "Density")
-        >>> frb1 = FixedResolutionBuffer(proj, (0.2, 0.3, 0.4, 0.5),
-                        (1024, 1024))
-        >>> print frb1["Density"].max()
-        1.0914e-9
-        >>> print frb1["Temperature"].max()
-        104923.1
-        """
         self.data_source = data_source
         self.pf = data_source.pf
         self.bounds = bounds
@@ -132,8 +134,9 @@ class FixedResolutionBuffer(object):
                              self.bounds, int(self.antialias),
                              self._period, int(self.periodic),
                              ).transpose()
-        self[item] = buff
-        return buff
+        ia = ImageArray(buff, info=self._get_info(item))
+        self[item] = ia
+        return ia 
 
     def __setitem__(self, item, val):
         self.data[item] = val
@@ -144,6 +147,55 @@ class FixedResolutionBuffer(object):
             if f not in exclude:
                 self[f]
 
+    def _get_info(self, item):
+        info = {}
+        info['data_source'] = self.data_source.__str__()  
+        info['axis'] = self.data_source.axis
+        info['field'] = str(item)
+        info['units'] = self.data_source.pf.field_info[item].get_units()
+        info['xlim'] = self.bounds[:2]
+        info['ylim'] = self.bounds[2:]
+        info['length_to_cm'] = self.data_source.pf['cm']
+        info['projected_units'] = \
+                self.data_source.pf.field_info[item].get_projected_units()
+        info['center'] = self.data_source.center
+        
+        try:
+            info['coord'] = self.data_source.coord
+        except AttributeError:
+            pass
+        
+        try:
+            info['weight_field'] = self.data_source.weight_field
+        except AttributeError:
+            pass
+        
+        info['label'] = self.data_source.pf.field_info[item].display_name
+        if info['label'] is None:
+            info['label'] = r'$\rm{'+item+r'}$'
+        elif info['label'].find('$') == -1:
+            info['label'] = info['label'].replace(' ','\/')
+            info['label'] = r'$\rm{'+info['label']+r'}$'
+        
+        # Try to determine the units of the data
+        units = None
+        if self.data_source._type_name in ("slice", "cutting"):
+            units = info['units']
+        elif self.data_source._type_name in ("proj", "overlap_proj"):
+            if (self.data_source.weight_field is not None or
+                self.data_source.proj_style == "mip"):
+                units = info['units']
+            else:
+                units = info['projected_units']
+        
+        if units is None or units == '':
+            pass
+        else:
+            info['label'] += r'$\/\/('+units+r')$'
+        
+
+        return info
+
     def convert_to_pixel(self, coords):
         r"""This function converts coordinates in code-space to pixel-space.
 
@@ -352,7 +404,7 @@ class FixedResolutionBuffer(object):
         """
         import numdisplay
         numdisplay.open()
-        if take_log: data=na.log10(self[field])
+        if take_log: data=np.log10(self[field])
         else: data=self[field]
         numdisplay.display(data)    
 
@@ -374,7 +426,7 @@ class ObliqueFixedResolutionBuffer(FixedResolutionBuffer):
     """
     def __getitem__(self, item):
         if item in self.data: return self.data[item]
-        indices = na.argsort(self.data_source['dx'])[::-1]
+        indices = np.argsort(self.data_source['dx'])[::-1]
         buff = _MPL.CPixelize( self.data_source['x'],   self.data_source['y'],   self.data_source['z'],
                                self.data_source['px'],  self.data_source['py'],
                                self.data_source['pdx'], self.data_source['pdy'], self.data_source['pdz'],
@@ -382,5 +434,32 @@ class ObliqueFixedResolutionBuffer(FixedResolutionBuffer):
                                self.data_source[item],
                                self.buff_size[0], self.buff_size[1],
                                self.bounds).transpose()
-        self[item] = buff
-        return buff
+        ia = ImageArray(buff, info=self._get_info(item))
+        self[item] = ia
+        return ia 
+
+
+class OffAxisProjectionFixedResolutionBuffer(FixedResolutionBuffer):
+    def __init__(self, data_source, bounds, buff_size, antialias = True,                                                         
+                 periodic = False):
+        self.data = {}
+        FixedResolutionBuffer.__init__(self, data_source, bounds, buff_size, antialias, periodic)
+
+    def __getitem__(self, item):
+        if item in self.data: return self.data[item]
+        mylog.info("Making a fixed resolutuion buffer of (%s) %d by %d" % \
+            (item, self.buff_size[0], self.buff_size[1]))
+        ds = self.data_source
+        width = (self.bounds[1] - self.bounds[0],
+                 self.bounds[3] - self.bounds[2],
+                 self.bounds[5] - self.bounds[4])
+        buff = off_axis_projection(ds.pf, ds.center, ds.normal_vector,
+                                   width, ds.resolution, item,
+                                   weight=ds.weight_field, volume=ds.volume,
+                                   no_ghost=ds.no_ghost, interpolated=ds.interpolated,
+                                   north_vector=ds.north_vector)
+        ia = ImageArray(buff.swapaxes(0,1), info=self._get_info(item))
+        self[item] = ia
+        return ia 
+
+
